timerelationtools.offset_happens_during_timespan
================================================

.. autofunction:: abjad.tools.timerelationtools.offset_happens_during_timespan.offset_happens_during_timespan
   :noindex:
